@@ -1,22 +1,14 @@
-import copy
 import logging
 import os
 import traceback
-from typing import Callable, Optional, Union
+from typing import Any, Callable, List, Optional, Union
 
-from ruamel.yaml import YAML, YAMLError
-from ruamel.yaml.compat import StringIO
+from ruamel.yaml import YAML
 
 import great_expectations.exceptions as ge_exceptions
 from great_expectations.core import ExpectationSuite
-from great_expectations.core.batch import (
-    Batch,
-    BatchDefinition,
-    BatchRequest,
-    PartitionRequest,
-)
+from great_expectations.core.batch import Batch, BatchRequest, PartitionRequest
 from great_expectations.data_context.data_context import DataContext
-from great_expectations.data_context.types.base import dataContextConfigSchema
 from great_expectations.data_context.util import (
     instantiate_class_from_config,
     substitute_all_config_variables,
@@ -33,40 +25,6 @@ yaml.default_flow_style = False
 class DataContextV3(DataContext):
     """Class implementing the v3 spec for DataContext configs, plus API changes for the 0.13+ series."""
 
-    def get_config(self, mode="typed"):
-        config = super().get_config()
-
-        if mode == "typed":
-            return config
-
-        elif mode == "commented_map":
-            return config.commented_map
-
-        elif mode == "dict":
-            return dict(config.commented_map)
-
-        elif mode == "yaml":
-            commented_map = copy.deepcopy(config.commented_map)
-            commented_map.update(dataContextConfigSchema.dump(config))
-
-            stream = StringIO()
-            yaml.dump(commented_map, stream)
-            yaml_string = stream.getvalue()
-
-            # print(commented_map)
-            # print(commented_map.__dict__)
-            # print(str(commented_map))
-            return yaml_string
-            # config.commented_map.update(dataContextConfigSchema.dump(self))
-
-        else:
-            raise ValueError(f"Unknown config mode {mode}")
-
-    @property
-    def config_variables(self):
-        # Note Abe 20121114 : We should probably cache config_variables instead of loading them from disk every time.
-        return dict(self._load_config_variables_file())
-
     # TODO: <Alex>We need to standardize the signatures of methods in all subclasses of BaseDataContext</Alex>
     # TODO: <Alex>Placing this method here avoids conflict with those in DataContext, handling LegacyDatasource</Alex>
     def add_datasource(self, datasource_name, datasource_config):
@@ -270,6 +228,7 @@ class DataContextV3(DataContext):
         data_asset_name: str = None,
         *,
         batch_request: BatchRequest = None,
+        batch_data: Any = None,
         partition_request: Union[PartitionRequest, dict] = None,
         partition_identifiers: dict = None,
         limit: int = None,
@@ -292,6 +251,7 @@ class DataContextV3(DataContext):
             data_asset_name
 
             batch_request
+            batch_data
             partition_request
             partition_identifiers
 
@@ -316,10 +276,94 @@ class DataContextV3(DataContext):
         In contrast to virtually all other methods in the class, it does not require typed or nested inputs.
         Instead, this method is intended to help the user pick the right parameters
 
-        This method attempts returns exactly one batch.
-        If 0 or more than batches would be returned, it raises an error.
+        This method attempts to return exactly one batch.
+        If 0 or more than 1 batches would be returned, it raises an error.
         """
 
+        batch_list: List[Batch] = self.get_batch_list(
+            datasource_name=datasource_name,
+            data_connector_name=data_connector_name,
+            data_asset_name=data_asset_name,
+            batch_request=batch_request,
+            batch_data=batch_data,
+            partition_request=partition_request,
+            partition_identifiers=partition_identifiers,
+            limit=limit,
+            index=index,
+            custom_filter_function=custom_filter_function,
+            batch_spec_passthrough=batch_spec_passthrough,
+            sampling_method=sampling_method,
+            sampling_kwargs=sampling_kwargs,
+            splitter_method=splitter_method,
+            splitter_kwargs=splitter_kwargs,
+            **kwargs,
+        )
+        # NOTE: Alex 20201202 - The check below is duplicate of code in Datasource.get_single_batch_from_batch_request()
+        if len(batch_list) != 1:
+            raise ValueError(
+                f"Got {len(batch_list)} batches instead of a single batch."
+            )
+        return batch_list[0]
+
+    def get_batch_list(
+        self,
+        datasource_name: str = None,
+        data_connector_name: str = None,
+        data_asset_name: str = None,
+        *,
+        batch_request: BatchRequest = None,
+        batch_data: Any = None,
+        partition_request: Union[PartitionRequest, dict] = None,
+        partition_identifiers: dict = None,
+        limit: int = None,
+        index=None,
+        custom_filter_function: Callable = None,
+        batch_spec_passthrough: Optional[dict] = None,
+        sampling_method: str = None,
+        sampling_kwargs: dict = None,
+        splitter_method: str = None,
+        splitter_kwargs: dict = None,
+        **kwargs,
+    ) -> List[Batch]:
+        """Get the list of zero or more batches, based on a variety of flexible input types.
+
+        Args:
+            batch_request
+
+            datasource_name
+            data_connector_name
+            data_asset_name
+
+            batch_request
+            batch_data
+            partition_request
+            partition_identifiers
+
+            limit
+            index
+            custom_filter_function
+
+            sampling_method
+            sampling_kwargs
+
+            splitter_method
+            splitter_kwargs
+
+            batch_spec_passthrough
+
+            **kwargs
+
+        Returns:
+            (Batch) The requested batch
+
+        `get_batch` is the main user-facing API for getting batches.
+        In contrast to virtually all other methods in the class, it does not require typed or nested inputs.
+        Instead, this method is intended to help the user pick the right parameters
+
+        This method attempts to return any number of batches, including an empty list.
+        """
+
+        datasource_name: str
         if batch_request:
             if not isinstance(batch_request, BatchRequest):
                 raise TypeError(
@@ -329,15 +373,14 @@ class DataContextV3(DataContext):
         else:
             datasource_name = datasource_name
 
-        datasource = self.datasources[datasource_name]
+        datasource: Datasource = self.datasources[datasource_name]
 
         if batch_request:
             # TODO: Raise a warning if any parameters besides batch_requests are specified
-            return datasource.get_single_batch_from_batch_request(
+            return datasource.get_batch_list_from_batch_request(
                 batch_request=batch_request
             )
         else:
-            partition_request: PartitionRequest
             if partition_request is None:
                 if partition_identifiers is None:
                     partition_identifiers = kwargs
@@ -383,10 +426,11 @@ class DataContextV3(DataContext):
                 datasource_name=datasource_name,
                 data_connector_name=data_connector_name,
                 data_asset_name=data_asset_name,
+                batch_data=batch_data,
                 partition_request=partition_request,
                 batch_spec_passthrough=batch_spec_passthrough,
             )
-            return datasource.get_single_batch_from_batch_request(
+            return datasource.get_batch_list_from_batch_request(
                 batch_request=batch_request
             )
 
@@ -397,6 +441,7 @@ class DataContextV3(DataContext):
         data_asset_name: str = None,
         *,
         batch_request: BatchRequest = None,
+        batch_data: Any = None,
         partition_request: Union[PartitionRequest, dict] = None,
         partition_identifiers: dict = None,
         limit: int = None,
@@ -440,6 +485,7 @@ class DataContextV3(DataContext):
             data_connector_name=data_connector_name,
             data_asset_name=data_asset_name,
             batch_request=batch_request,
+            batch_data=batch_data,
             partition_request=partition_request,
             partition_identifiers=partition_identifiers,
             limit=limit,
