@@ -1,11 +1,18 @@
+import abc
+import enum
 import logging
 import uuid
 from copy import deepcopy
+from typing import Dict, Optional, Union
 
 from ruamel.yaml import YAML
 from ruamel.yaml.comments import CommentedMap
+from ruamel.yaml.compat import StringIO
 
 import great_expectations.exceptions as ge_exceptions
+
+# TODO: <Alex></Alex>
+from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.marshmallow__shade import (
     INCLUDE,
     Schema,
@@ -15,7 +22,7 @@ from great_expectations.marshmallow__shade import (
     post_load,
     validates_schema,
 )
-from great_expectations.types import DictDot
+from great_expectations.types import DictDot, SerializableDictDot
 from great_expectations.types.configurations import ClassConfigSchema
 
 logger = logging.getLogger(__name__)
@@ -29,28 +36,26 @@ DEFAULT_USAGE_STATISTICS_URL = (
 )
 
 
+def object_to_yaml_str(obj):
+    output_str: str
+    with StringIO() as string_stream:
+        yaml.dump(obj, string_stream)
+        output_str = string_stream.getvalue()
+    return output_str
+
+
 class AssetConfig(DictDot):
     def __init__(
-        self,
-        # partitioner_name=None,
-        **kwargs,
+        self, **kwargs,
     ):
-        # if partitioner_name is not None:
-        #     self._partitioner_name = partitioner_name
         for k, v in kwargs.items():
             setattr(self, k, v)
 
-    # @property
-    # def partitioner_name(self):
-    #     return self._partitioner_name
-
 
 class AssetConfigSchema(Schema):
     class Meta:
         unknown = INCLUDE
 
-    # partitioner_name = fields.String(required=False, allow_none=True)
-
     @validates_schema
     def validate_schema(self, data, **kwargs):
         pass
@@ -96,7 +101,7 @@ class SorterConfigSchema(Schema):
     name = fields.String(required=True)
     class_name = fields.String(required=True)
     module_name = fields.String(
-        missing="great_expectations.datasource.data_connector.partitioner.sorter"
+        missing="great_expectations.datasource.data_connector.sorter"
     )
     orderby = fields.String(required=False, missing="asc", allow_none=False)
 
@@ -110,110 +115,17 @@ class SorterConfigSchema(Schema):
         return SorterConfig(**data)
 
 
-class PartitionerConfig(DictDot):
-    def __init__(
-        self,
-        class_name,
-        module_name=None,
-        sorters=None,
-        allow_multipart_partitions=False,
-        runtime_keys=None,
-        **kwargs,
-    ):
-        self._class_name = class_name
-        self._module_name = module_name
-        if sorters is not None:
-            self._sorters = sorters
-        self._allow_multipart_partitions = allow_multipart_partitions
-        if runtime_keys is not None:
-            self._runtime_keys = runtime_keys
-        for k, v in kwargs.items():
-            setattr(self, k, v)
-
-    @property
-    def class_name(self):
-        return self._class_name
-
-    @property
-    def module_name(self):
-        return self._module_name
-
-    @property
-    def sorters(self):
-        return self._sorters
-
-    @property
-    def allow_multipart_partitions(self):
-        return self._allow_multipart_partitions
-
-    @property
-    def runtime_keys(self):
-        return self._runtime_keys
-
-
-class PartitionerConfigSchema(Schema):
-    class Meta:
-        unknown = INCLUDE
-
-    class_name = fields.String(required=True)
-    module_name = fields.String(
-        missing="great_expectations.datasource.data_connector.partitioner"
-    )
-
-    sorters = fields.List(
-        cls_or_instance=fields.Nested(SorterConfigSchema),
-        required=False,
-        allow_none=True,
-    )
-
-    allow_multipart_partitions = fields.Boolean(
-        required=False, missing=False, allow_none=False
-    )
-
-    runtime_keys = fields.List(
-        cls_or_instance=fields.String(), required=False, allow_none=True
-    )
-
-    @validates_schema
-    def validate_schema(self, data, **kwargs):
-        pass
-
-    # noinspection PyUnusedLocal
-    @post_load
-    def make_partitioner_config(self, data, **kwargs):
-        return PartitionerConfig(**data)
-
-
-# TODO: <Alex></Alex>
 class DataConnectorConfig(DictDot):
     def __init__(
-        self,
-        class_name,
-        module_name=None,
-        # partitioners=None,
-        # default_partitioner_name=None,
-        assets=None,
-        **kwargs,
+        self, class_name, module_name=None, assets=None, **kwargs,
     ):
         self._class_name = class_name
         self._module_name = module_name
-        # if partitioners is not None:
-        #     self._partitioners = partitioners
-        # if default_partitioner_name is not None:
-        #     self._default_partitioner_name = default_partitioner_name
         if assets is not None:
             self._assets = assets
         for k, v in kwargs.items():
             setattr(self, k, v)
 
-    # @property
-    # def partitioners(self):
-    #     return self._partitioners
-
-    # @property
-    # def default_partitioner_name(self):
-    #     return self._default_partitioner_name
-
     @property
     def assets(self):
         return self._assets
@@ -241,19 +153,6 @@ class DataConnectorConfigSchema(Schema):
         allow_none=True,
     )
 
-    # TODO: <Alex></Alex>
-    # partitioners = fields.Dict(
-    #     keys=fields.Str(),
-    #     values=fields.Nested(PartitionerConfigSchema),
-    #     required=False,
-    #     allow_none=True,
-    # )
-
-    # default_partitioner_name = fields.String(
-    #     required=False,
-    #     allow_none=True,
-    # )
-
     @validates_schema
     def validate_schema(self, data, **kwargs):
         pass
@@ -301,8 +200,8 @@ class ExecutionEngineConfigSchema(Schema):
 
     class_name = fields.String(required=True)
     module_name = fields.String(missing="great_expectations.execution_engine")
-    caching = fields.Boolean()
-    batch_spec_defaults = fields.Dict(allow_none=True)
+    caching = fields.Boolean(required=False, allow_none=True)
+    batch_spec_defaults = fields.Dict(required=False, allow_none=True)
 
     @validates_schema
     def validate_schema(self, data, **kwargs):
@@ -318,10 +217,13 @@ class DatasourceConfig(DictDot):
     def __init__(
         self,
         class_name=None,
-        module_name=None,
+        module_name: Optional[str] = "great_expectations.datasource",
         execution_engine=None,
         data_connectors=None,
+        data_asset_type=None,
+        batch_kwargs_generators=None,
         credentials=None,
+        boto3_options=None,
         reader_method=None,
         limit=None,
         **kwargs,
@@ -329,12 +231,35 @@ class DatasourceConfig(DictDot):
         # NOTE - JPC - 20200316: Currently, we are mostly inconsistent with respect to this type...
         self._class_name = class_name
         self._module_name = module_name
-        self.execution_engine = execution_engine
-        if data_connectors is None:
-            data_connectors = {}
-        self.data_connectors = data_connectors
+        if execution_engine is not None:
+            self.execution_engine = execution_engine
+        if data_connectors is not None and isinstance(data_connectors, dict):
+            self.data_connectors = data_connectors
+
+        # NOTE - AJB - 20201202: This should use the datasource class build_configuration method as in DataContext.add_datasource()
+        if data_asset_type is None:
+            if class_name == "PandasDatasource":
+                data_asset_type = {
+                    "class_name": "PandasDataset",
+                    "module_name": "great_expectations.dataset",
+                }
+            elif class_name == "SqlAlchemyDatasource":
+                data_asset_type = {
+                    "class_name": "SqlAlchemyDataset",
+                    "module_name": "great_expectations.dataset",
+                }
+            elif class_name == "SparkDFDatasource":
+                data_asset_type = {
+                    "class_name": "SparkDFDataset",
+                    "module_name": "great_expectations.dataset",
+                }
+        self.data_asset_type = data_asset_type
+        if batch_kwargs_generators is not None:
+            self.batch_kwargs_generators = batch_kwargs_generators
         if credentials is not None:
             self.credentials = credentials
+        if boto3_options is not None:
+            self.boto3_options = boto3_options
         if reader_method is not None:
             self.reader_method = reader_method
         if limit is not None:
@@ -357,21 +282,37 @@ class DatasourceConfigSchema(Schema):
 
     class_name = fields.String(missing="Datasource")
     module_name = fields.String(missing="great_expectations.datasource")
-    execution_engine = fields.Nested(ExecutionEngineConfigSchema)
 
+    execution_engine = fields.Nested(
+        ExecutionEngineConfigSchema, required=False, allow_none=True
+    )
     data_connectors = fields.Dict(
         keys=fields.Str(),
         values=fields.Nested(DataConnectorConfigSchema),
-        required=True,
-        allow_none=False,
+        required=False,
+        allow_none=True,
     )
 
-    credentials = fields.Raw(allow_none=True)
-    spark_context = fields.Raw(allow_none=True)
+    data_asset_type = fields.Nested(ClassConfigSchema)
+    boto3_options = fields.Dict(
+        keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
+    )
+
+    # TODO: Update to generator-specific
+    # batch_kwargs_generators = fields.Mapping(keys=fields.Str(), values=fields.Nested(fields.GeneratorSchema))
+    batch_kwargs_generators = fields.Dict(
+        keys=fields.Str(), values=fields.Dict(), required=False, allow_none=True
+    )
+    credentials = fields.Raw(required=False, allow_none=True)
+    spark_config = fields.Raw(required=False, allow_none=True)
 
     @validates_schema
     def validate_schema(self, data, **kwargs):
-        pass
+        if "generators" in data:
+            raise ge_exceptions.InvalidConfigError(
+                "Your current configuration uses the 'generators' key in a datasource, but in version 0.10 of "
+                "GE, that key is renamed to 'batch_kwargs_generators'. Please update your config to continue."
+            )
 
     # noinspection PyUnusedLocal
     @post_load
@@ -379,45 +320,6 @@ class DatasourceConfigSchema(Schema):
         return DatasourceConfig(**data)
 
 
-class LegacyDatasourceConfig(DictDot):
-    def __init__(
-        self,
-        class_name,
-        module_name=None,
-        data_asset_type=None,
-        batch_kwargs_generators=None,
-        credentials=None,
-        boto3_options=None,
-        reader_method=None,
-        limit=None,
-        **kwargs,
-    ):
-        # NOTE - JPC - 20200316: Currently, we are mostly inconsistent with respect to this type...
-        self._class_name = class_name
-        self._module_name = module_name
-        self.data_asset_type = data_asset_type
-        if batch_kwargs_generators is not None:
-            self.batch_kwargs_generators = batch_kwargs_generators
-        if credentials is not None:
-            self.credentials = credentials
-        if reader_method is not None:
-            self.reader_method = reader_method
-        if limit is not None:
-            self.limit = limit
-        for k, v in kwargs.items():
-            setattr(self, k, v)
-        if boto3_options is not None:
-            self.boto3_options = boto3_options
-
-    @property
-    def class_name(self):
-        return self._class_name
-
-    @property
-    def module_name(self):
-        return self._module_name
-
-
 class AnonymizedUsageStatisticsConfig(DictDot):
     def __init__(self, enabled=True, data_context_id=None, usage_statistics_url=None):
         self._enabled = enabled
@@ -497,36 +399,6 @@ class AnonymizedUsageStatisticsConfigSchema(Schema):
         return data
 
 
-class LegacyDatasourceConfigSchema(Schema):
-    class Meta:
-        unknown = INCLUDE
-
-    class_name = fields.String(required=True)
-    module_name = fields.String(missing="great_expectations.datasource")
-    data_asset_type = fields.Nested(ClassConfigSchema)
-    boto3_options = fields.Dict(keys=fields.Str(), values=fields.Str(), allow_none=True)
-    # TODO: Update to generator-specific
-    # batch_kwargs_generators = fields.Mapping(keys=fields.Str(), values=fields.Nested(fields.GeneratorSchema))
-    batch_kwargs_generators = fields.Dict(
-        keys=fields.Str(), values=fields.Dict(), allow_none=True
-    )
-    credentials = fields.Raw(allow_none=True)
-    spark_context = fields.Raw(allow_none=True)
-
-    @validates_schema
-    def validate_schema(self, data, **kwargs):
-        if "generators" in data:
-            raise ge_exceptions.InvalidConfigError(
-                "Your current configuration uses the 'generators' key in a datasource, but in version 0.10 of "
-                "GE, that key is renamed to 'batch_kwargs_generators'. Please update your config to continue."
-            )
-
-    # noinspection PyUnusedLocal
-    @post_load
-    def make_datasource_config(self, data, **kwargs):
-        return LegacyDatasourceConfig(**data)
-
-
 class NotebookTemplateConfig(DictDot):
     def __init__(self, file_name, template_kwargs=None):
         self.file_name = file_name
@@ -649,76 +521,6 @@ class NotebooksConfigSchema(Schema):
         return NotebooksConfig(**data)
 
 
-class DataContextConfig(DictDot):
-    def __init__(
-        self,
-        config_version,
-        expectations_store_name,
-        validations_store_name,
-        evaluation_parameter_store_name,
-        plugins_directory,
-        validation_operators,
-        stores,
-        data_docs_sites,
-        notebooks=None,
-        config_variables_file_path=None,
-        anonymous_usage_statistics=None,
-        commented_map=None,
-        datasources=None,
-    ):
-        if commented_map is None:
-            commented_map = CommentedMap()
-        self._commented_map = commented_map
-        self._config_version = config_version
-        if datasources is None:
-            datasources = {}
-        self.datasources = datasources
-        self.expectations_store_name = expectations_store_name
-        self.validations_store_name = validations_store_name
-        self.evaluation_parameter_store_name = evaluation_parameter_store_name
-        self.plugins_directory = plugins_directory
-        if not isinstance(validation_operators, dict):
-            raise ValueError(
-                "validation_operators must be configured with a dictionary"
-            )
-        self.validation_operators = validation_operators
-        self.stores = stores
-        self.notebooks = notebooks
-        self.data_docs_sites = data_docs_sites
-        self.config_variables_file_path = config_variables_file_path
-        if anonymous_usage_statistics is None:
-            anonymous_usage_statistics = AnonymizedUsageStatisticsConfig()
-        elif isinstance(anonymous_usage_statistics, dict):
-            anonymous_usage_statistics = AnonymizedUsageStatisticsConfig(
-                **anonymous_usage_statistics
-            )
-        self.anonymous_usage_statistics = anonymous_usage_statistics
-
-    @property
-    def commented_map(self):
-        return self._commented_map
-
-    @property
-    def config_version(self):
-        return self._config_version
-
-    @classmethod
-    def from_commented_map(cls, commented_map):
-        try:
-            config = dataContextConfigSchema.load(commented_map)
-            return cls(commented_map=commented_map, **config)
-        except ValidationError:
-            logger.error(
-                "Encountered errors during loading data context config. See ValidationError for more details."
-            )
-            raise
-
-    def to_yaml(self, outfile):
-        commented_map = deepcopy(self.commented_map)
-        commented_map.update(dataContextConfigSchema.dump(self))
-        yaml.dump(commented_map, outfile)
-
-
 class DataContextConfigSchema(Schema):
     config_version = fields.Number(
         validate=lambda x: 0 < x < 100,
@@ -727,7 +529,8 @@ class DataContextConfigSchema(Schema):
     # TODO: <Alex>Proper Schema enforcement for the new Datasource must be implemented.</Alex>
     datasources = fields.Dict(
         keys=fields.Str(),
-        values=fields.Nested(LegacyDatasourceConfigSchema),
+        values=fields.Nested(DatasourceConfigSchema),
+        required=False,
         allow_none=True,
     )
     expectations_store_name = fields.Str()
@@ -790,12 +593,497 @@ class DataContextConfigSchema(Schema):
             )
 
 
+class DataContextConfigDefaults(enum.Enum):
+    DEFAULT_CONFIG_VERSION = CURRENT_CONFIG_VERSION
+    DEFAULT_EXPECTATIONS_STORE_NAME = "expectations_store"
+    DEFAULT_VALIDATIONS_STORE_NAME = "validations_store"
+    DEFAULT_EVALUATION_PARAMETER_STORE_NAME = "evaluation_parameter_store"
+    DEFAULT_DATA_DOCS_SITE_NAME = "local_site"
+    DEFAULT_CONFIG_VARIABLES_FILEPATH = "uncommitted/config_variables.yml"
+    DEFAULT_PLUGINS_DIRECTORY = "plugins/"
+    DEFAULT_VALIDATION_OPERATORS = {
+        "action_list_operator": {
+            "class_name": "ActionListValidationOperator",
+            "action_list": [
+                {
+                    "name": "store_validation_result",
+                    "action": {"class_name": "StoreValidationResultAction"},
+                },
+                {
+                    "name": "store_evaluation_params",
+                    "action": {"class_name": "StoreEvaluationParametersAction"},
+                },
+                {
+                    "name": "update_data_docs",
+                    "action": {"class_name": "UpdateDataDocsAction"},
+                },
+            ],
+        }
+    }
+    DEFAULT_STORES = {
+        DEFAULT_EXPECTATIONS_STORE_NAME: {
+            "class_name": "ExpectationsStore",
+            "store_backend": {
+                "class_name": "TupleFilesystemStoreBackend",
+                "base_directory": "expectations/",
+            },
+        },
+        DEFAULT_VALIDATIONS_STORE_NAME: {
+            "class_name": "ValidationsStore",
+            "store_backend": {
+                "class_name": "TupleFilesystemStoreBackend",
+                "base_directory": "uncommitted/validations/",
+            },
+        },
+        DEFAULT_EVALUATION_PARAMETER_STORE_NAME: {
+            "class_name": "EvaluationParameterStore"
+        },
+    }
+    DEFAULT_DATA_DOCS_SITES = {
+        DEFAULT_DATA_DOCS_SITE_NAME: {
+            "class_name": "SiteBuilder",
+            "store_backend": {
+                "class_name": "TupleFilesystemStoreBackend",
+                "base_directory": "uncommitted/data_docs/local_site/",
+            },
+            "site_index_builder": {
+                "class_name": "DefaultSiteIndexBuilder",
+                "show_cta_footer": True,
+            },
+            "show_how_to_buttons": True,
+        }
+    }
+
+
+class BaseStoreBackendDefaults(DictDot):
+    """
+    Define base defaults for platform specific StoreBackendDefaults.
+    StoreBackendDefaults define defaults for specific cases of often used configurations.
+    For example, if you plan to store expectations, validations, and data_docs in s3 use the S3StoreBackendDefaults and you may be able to specify less parameters.
+    """
+
+    def __init__(
+        self,
+        expectations_store_name: str = DataContextConfigDefaults.DEFAULT_EXPECTATIONS_STORE_NAME.value,
+        validations_store_name=(
+            DataContextConfigDefaults.DEFAULT_VALIDATIONS_STORE_NAME.value
+        ),
+        evaluation_parameter_store_name=(
+            DataContextConfigDefaults.DEFAULT_EVALUATION_PARAMETER_STORE_NAME.value
+        ),
+        data_docs_site_name=(
+            DataContextConfigDefaults.DEFAULT_DATA_DOCS_SITE_NAME.value
+        ),
+        validation_operators=None,
+        stores=None,
+        data_docs_sites=None,
+    ):
+        self.expectations_store_name = expectations_store_name
+        self.validations_store_name = validations_store_name
+        self.evaluation_parameter_store_name = evaluation_parameter_store_name
+        if validation_operators is None:
+            validation_operators = deepcopy(
+                DataContextConfigDefaults.DEFAULT_VALIDATION_OPERATORS.value
+            )
+        self.validation_operators = validation_operators
+        if stores is None:
+            stores = deepcopy(DataContextConfigDefaults.DEFAULT_STORES.value)
+        self.stores = stores
+        if data_docs_sites is None:
+            data_docs_sites = deepcopy(
+                DataContextConfigDefaults.DEFAULT_DATA_DOCS_SITES.value
+            )
+        self.data_docs_sites = data_docs_sites
+        self.data_docs_site_name = data_docs_site_name
+
+
+class S3StoreBackendDefaults(BaseStoreBackendDefaults):
+    """
+    Default store configs for s3 backends, with some accessible parameters
+    Args:
+        default_bucket_name: Use this bucket name for stores that do not have a bucket name provided
+        expectations_store_bucket_name: Overrides default_bucket_name if supplied
+        validations_store_bucket_name: Overrides default_bucket_name if supplied
+        data_docs_bucket_name: Overrides default_bucket_name if supplied
+        expectations_store_prefix: Overrides default if supplied
+        validations_store_prefix: Overrides default if supplied
+        data_docs_prefix: Overrides default if supplied
+        expectations_store_name: Overrides default if supplied
+        validations_store_name: Overrides default if supplied
+        evaluation_parameter_store_name: Overrides default if supplied
+    """
+
+    def __init__(
+        self,
+        default_bucket_name: Optional[str] = None,
+        expectations_store_bucket_name: Optional[str] = None,
+        validations_store_bucket_name: Optional[str] = None,
+        data_docs_bucket_name: Optional[str] = None,
+        expectations_store_prefix: str = "expectations",
+        validations_store_prefix: str = "validations",
+        data_docs_prefix: str = "data_docs",
+        expectations_store_name: str = "expectations_S3_store",
+        validations_store_name: str = "validations_S3_store",
+        evaluation_parameter_store_name: str = "evaluation_parameter_store",
+    ):
+        # Initialize base defaults
+        super().__init__()
+
+        # Use default_bucket_name if separate store buckets are not provided
+        if expectations_store_bucket_name is None:
+            expectations_store_bucket_name = default_bucket_name
+        if validations_store_bucket_name is None:
+            validations_store_bucket_name = default_bucket_name
+        if data_docs_bucket_name is None:
+            data_docs_bucket_name = default_bucket_name
+
+        # Overwrite defaults
+        self.expectations_store_name = expectations_store_name
+        self.validations_store_name = validations_store_name
+        self.evaluation_parameter_store_name = evaluation_parameter_store_name
+        self.stores = {
+            expectations_store_name: {
+                "class_name": "ExpectationsStore",
+                "store_backend": {
+                    "class_name": "TupleS3StoreBackend",
+                    "bucket": expectations_store_bucket_name,
+                    "prefix": expectations_store_prefix,
+                },
+            },
+            validations_store_name: {
+                "class_name": "ValidationsStore",
+                "store_backend": {
+                    "class_name": "TupleS3StoreBackend",
+                    "bucket": validations_store_bucket_name,
+                    "prefix": validations_store_prefix,
+                },
+            },
+            evaluation_parameter_store_name: {"class_name": "EvaluationParameterStore"},
+        }
+        self.data_docs_sites = {
+            "s3_site": {
+                "class_name": "SiteBuilder",
+                "show_how_to_buttons": True,
+                "store_backend": {
+                    "class_name": "TupleS3StoreBackend",
+                    "bucket": data_docs_bucket_name,
+                    "prefix": data_docs_prefix,
+                },
+                "site_index_builder": {
+                    "class_name": "DefaultSiteIndexBuilder",
+                    "show_cta_footer": True,
+                },
+            }
+        }
+
+
+class FilesystemStoreBackendDefaults(BaseStoreBackendDefaults):
+    """
+    Default store configs for filesystem backends, with some accessible parameters
+    Args:
+        root_directory: Absolute directory prepended to the base_directory for each store
+        plugins_directory: Overrides default if supplied
+    """
+
+    def __init__(
+        self,
+        root_directory: Optional[str] = None,
+        plugins_directory: Optional[str] = None,
+    ):
+        # Initialize base defaults
+        super().__init__()
+
+        if plugins_directory is None:
+            plugins_directory = (
+                DataContextConfigDefaults.DEFAULT_PLUGINS_DIRECTORY.value
+            )
+        self.plugins_directory = plugins_directory
+        if root_directory is not None:
+            self.stores[self.expectations_store_name]["store_backend"][
+                "root_directory"
+            ] = root_directory
+            self.stores[self.validations_store_name]["store_backend"][
+                "root_directory"
+            ] = root_directory
+            self.data_docs_sites[self.data_docs_site_name]["store_backend"][
+                "root_directory"
+            ] = root_directory
+
+
+class GCSStoreBackendDefaults(BaseStoreBackendDefaults):
+    """
+    Default store configs for Google Cloud Storage (GCS) backends, with some accessible parameters
+    Args:
+        default_bucket_name: Use this bucket name for stores that do not have a bucket name provided
+        default_project_name: Use this project name for stores that do not have a project name provided
+        expectations_store_bucket_name: Overrides default_bucket_name if supplied
+        validations_store_bucket_name: Overrides default_bucket_name if supplied
+        data_docs_bucket_name: Overrides default_bucket_name if supplied
+        expectations_store_project_name: Overrides default_project_name if supplied
+        validations_store_project_name: Overrides default_project_name if supplied
+        data_docs_project_name: Overrides default_project_name if supplied
+        expectations_store_prefix: Overrides default if supplied
+        validations_store_prefix: Overrides default if supplied
+        data_docs_prefix: Overrides default if supplied
+        expectations_store_name: Overrides default if supplied
+        validations_store_name: Overrides default if supplied
+        evaluation_parameter_store_name: Overrides default if supplied
+    """
+
+    def __init__(
+        self,
+        default_bucket_name: Optional[str] = None,
+        default_project_name: Optional[str] = None,
+        expectations_store_bucket_name: Optional[str] = None,
+        validations_store_bucket_name: Optional[str] = None,
+        data_docs_bucket_name: Optional[str] = None,
+        expectations_store_project_name: Optional[str] = None,
+        validations_store_project_name: Optional[str] = None,
+        data_docs_project_name: Optional[str] = None,
+        expectations_store_prefix: str = "expectations",
+        validations_store_prefix: str = "validations",
+        data_docs_prefix: str = "data_docs",
+        expectations_store_name: str = "expectations_GCS_store",
+        validations_store_name: str = "validations_GCS_store",
+        evaluation_parameter_store_name: str = "evaluation_parameter_store",
+    ):
+        # Initialize base defaults
+        super().__init__()
+
+        # Use default_bucket_name if separate store buckets are not provided
+        if expectations_store_bucket_name is None:
+            expectations_store_bucket_name = default_bucket_name
+        if validations_store_bucket_name is None:
+            validations_store_bucket_name = default_bucket_name
+        if data_docs_bucket_name is None:
+            data_docs_bucket_name = default_bucket_name
+
+        # Use default_project_name if separate store projects are not provided
+        if expectations_store_project_name is None:
+            expectations_store_project_name = default_project_name
+        if validations_store_project_name is None:
+            validations_store_project_name = default_project_name
+        if data_docs_project_name is None:
+            data_docs_project_name = default_project_name
+
+        # Overwrite defaults
+        self.expectations_store_name = expectations_store_name
+        self.validations_store_name = validations_store_name
+        self.evaluation_parameter_store_name = evaluation_parameter_store_name
+        self.stores = {
+            expectations_store_name: {
+                "class_name": "ExpectationsStore",
+                "store_backend": {
+                    "class_name": "TupleGCSStoreBackend",
+                    "project": expectations_store_project_name,
+                    "bucket": expectations_store_bucket_name,
+                    "prefix": expectations_store_prefix,
+                },
+            },
+            validations_store_name: {
+                "class_name": "ValidationsStore",
+                "store_backend": {
+                    "class_name": "TupleGCSStoreBackend",
+                    "project": validations_store_project_name,
+                    "bucket": validations_store_bucket_name,
+                    "prefix": validations_store_prefix,
+                },
+            },
+            evaluation_parameter_store_name: {"class_name": "EvaluationParameterStore"},
+        }
+        self.data_docs_sites = {
+            "gcs_site": {
+                "class_name": "SiteBuilder",
+                "show_how_to_buttons": True,
+                "store_backend": {
+                    "class_name": "TupleGCSStoreBackend",
+                    "project": data_docs_project_name,
+                    "bucket": data_docs_bucket_name,
+                    "prefix": data_docs_prefix,
+                },
+                "site_index_builder": {
+                    "class_name": "DefaultSiteIndexBuilder",
+                    "show_cta_footer": True,
+                },
+            }
+        }
+
+
+class DatabaseStoreBackendDefaults(BaseStoreBackendDefaults):
+    """
+    Default store configs for database backends, with some accessible parameters
+    Args:
+        default_credentials: Use these credentials for all stores that do not have credentials provided
+        expectations_store_credentials: Overrides default_credentials if supplied
+        validations_store_credentials: Overrides default_credentials if supplied
+        expectations_store_name: Overrides default if supplied
+        validations_store_name: Overrides default if supplied
+        evaluation_parameter_store_name: Overrides default if supplied
+    """
+
+    def __init__(
+        self,
+        default_credentials: Optional[Dict] = None,
+        expectations_store_credentials: Optional[Dict] = None,
+        validations_store_credentials: Optional[Dict] = None,
+        expectations_store_name: str = "expectations_database_store",
+        validations_store_name: str = "validations_database_store",
+        evaluation_parameter_store_name: str = "evaluation_parameter_store",
+    ):
+        # Initialize base defaults
+        super().__init__()
+
+        # Use default credentials if seprate credentials not supplied for expectations_store and validations_store
+        if expectations_store_credentials is None:
+            expectations_store_credentials = default_credentials
+        if validations_store_credentials is None:
+            validations_store_credentials = default_credentials
+
+        # Overwrite defaults
+        self.expectations_store_name = expectations_store_name
+        self.validations_store_name = validations_store_name
+        self.evaluation_parameter_store_name = evaluation_parameter_store_name
+
+        self.stores = {
+            expectations_store_name: {
+                "class_name": "ExpectationsStore",
+                "store_backend": {
+                    "class_name": "DatabaseStoreBackend",
+                    "credentials": expectations_store_credentials,
+                },
+            },
+            validations_store_name: {
+                "class_name": "ValidationsStore",
+                "store_backend": {
+                    "class_name": "DatabaseStoreBackend",
+                    "credentials": validations_store_credentials,
+                },
+            },
+            evaluation_parameter_store_name: {"class_name": "EvaluationParameterStore"},
+        }
+
+
+class DataContextConfig(SerializableDictDot):
+    def __init__(
+        self,
+        config_version: Optional[float] = None,
+        datasources: Optional[
+            Union[
+                Dict[str, DatasourceConfig],
+                Dict[str, Dict[str, Union[Dict[str, str], str, dict]]],
+            ]
+        ] = None,
+        expectations_store_name: Optional[str] = None,
+        validations_store_name: Optional[str] = None,
+        evaluation_parameter_store_name: Optional[str] = None,
+        plugins_directory: Optional[str] = None,
+        validation_operators=None,
+        stores: Optional[Dict] = None,
+        data_docs_sites: Optional[Dict] = None,
+        notebooks=None,
+        config_variables_file_path: Optional[str] = None,
+        anonymous_usage_statistics=None,
+        commented_map=None,
+        store_backend_defaults: Optional[BaseStoreBackendDefaults] = None,
+    ):
+        # Set defaults
+        if config_version is None:
+            config_version = DataContextConfigDefaults.DEFAULT_CONFIG_VERSION.value
+
+        # Set defaults via store_backend_defaults if one is passed in
+        # Override attributes from store_backend_defaults with any items passed into the constructor:
+        if store_backend_defaults is not None:
+            if stores is None:
+                stores = store_backend_defaults.stores
+            if expectations_store_name is None:
+                expectations_store_name = store_backend_defaults.expectations_store_name
+            if validations_store_name is None:
+                validations_store_name = store_backend_defaults.validations_store_name
+            if evaluation_parameter_store_name is None:
+                evaluation_parameter_store_name = (
+                    store_backend_defaults.evaluation_parameter_store_name
+                )
+            if validation_operators is None:
+                validation_operators = store_backend_defaults.validation_operators
+            if data_docs_sites is None:
+                data_docs_sites = store_backend_defaults.data_docs_sites
+
+        if commented_map is None:
+            commented_map = CommentedMap()
+        self._commented_map = commented_map
+        self._config_version = config_version
+        if datasources is None:
+            datasources = {}
+        self.datasources = datasources
+        self.expectations_store_name = expectations_store_name
+        self.validations_store_name = validations_store_name
+        self.evaluation_parameter_store_name = evaluation_parameter_store_name
+        self.plugins_directory = plugins_directory
+        if not isinstance(validation_operators, dict):
+            raise ValueError(
+                "validation_operators must be configured with a dictionary"
+            )
+        self.validation_operators = validation_operators
+        self.stores = stores
+        self.notebooks = notebooks
+        self.data_docs_sites = data_docs_sites
+        self.config_variables_file_path = config_variables_file_path
+        if anonymous_usage_statistics is None:
+            anonymous_usage_statistics = AnonymizedUsageStatisticsConfig()
+        elif isinstance(anonymous_usage_statistics, dict):
+            anonymous_usage_statistics = AnonymizedUsageStatisticsConfig(
+                **anonymous_usage_statistics
+            )
+        self.anonymous_usage_statistics = anonymous_usage_statistics
+
+    @property
+    def commented_map(self):
+        return self._commented_map
+
+    @property
+    def config_version(self):
+        return self._config_version
+
+    @classmethod
+    def from_commented_map(cls, commented_map):
+        try:
+            config = dataContextConfigSchema.load(commented_map)
+            return cls(commented_map=commented_map, **config)
+        except ValidationError:
+            logger.error(
+                "Encountered errors during loading data context config. See ValidationError for more details."
+            )
+            raise
+
+    def get_schema_validated_updated_commented_map(self) -> CommentedMap:
+        commented_map: CommentedMap = deepcopy(self.commented_map)
+        commented_map.update(dataContextConfigSchema.dump(self))
+        return commented_map
+
+    def to_yaml(self, outfile):
+        """
+        :returns None (but writes a YAML file containing the project configuration)
+        """
+        yaml.dump(self.get_schema_validated_updated_commented_map(), outfile)
+
+    def to_yaml_str(self) -> str:
+        """
+        :returns a YAML string containing the project configuration
+        """
+        return object_to_yaml_str(self.get_schema_validated_updated_commented_map())
+
+    def to_json_dict(self) -> dict:
+        """
+        :returns a JSON-serialiable dict containing the project configuration
+        """
+        commented_map: CommentedMap = self.get_schema_validated_updated_commented_map()
+        return convert_to_json_serializable(data=commented_map)
+
+
 dataContextConfigSchema = DataContextConfigSchema()
-legacyDatasourceConfigSchema = LegacyDatasourceConfigSchema()
 datasourceConfigSchema = DatasourceConfigSchema()
 dataConnectorConfigSchema = DataConnectorConfigSchema()
 assetConfigSchema = AssetConfigSchema()
-partitionerConfigSchema = PartitionerConfigSchema()
 sorterConfigSchema = SorterConfigSchema()
 anonymizedUsageStatisticsSchema = AnonymizedUsageStatisticsConfigSchema()
 notebookConfigSchema = NotebookConfigSchema()
